summaryrefslogtreecommitdiff
path: root/sw/source/core/doc/docsort.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/doc/docsort.cxx')
-rw-r--r--sw/source/core/doc/docsort.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sw/source/core/doc/docsort.cxx b/sw/source/core/doc/docsort.cxx
index 4619226d5c61..520500047ef9 100644
--- a/sw/source/core/doc/docsort.cxx
+++ b/sw/source/core/doc/docsort.cxx
@@ -532,12 +532,12 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
// Delete HTML layout
pTableNd->GetTable().SetHTMLTableLayout( nullptr );
// #i37739# A simple 'MakeFrms' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
SwNode2Layout aNode2Layout( *pTableNd );
// Delete the Table's Frames
- pTableNd->DelFrms();
+ pTableNd->DelFrames();
// ? TL_CHART2: ?
SwUndoSort* pUndoSort = nullptr;
@@ -581,10 +581,10 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
}
// Restore table frames:
// #i37739# A simple 'MakeFrms' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
const sal_uLong nIdx = pTableNd->GetIndex();
- aNode2Layout.RestoreUpperFrms( GetNodes(), nIdx, nIdx + 1 );
+ aNode2Layout.RestoreUpperFrames( GetNodes(), nIdx, nIdx + 1 );
// TL_CHART2: need to inform chart of probably changed cell names
UpdateCharts( pTableNd->GetTable().GetFrameFormat()->GetName() );
@@ -532,12 +532,12 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
// Delete HTML layout
pTableNd->GetTable().SetHTMLTableLayout( nullptr );
- // #i37739# A simple 'MakeFrms' after the node sorting
+ // #i37739# A simple 'MakeFrames' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
SwNode2Layout aNode2Layout( *pTableNd );
@@ -581,10 +581,10 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
}
// Restore table frames:
- // #i37739# A simple 'MakeFrms' after the node sorting
+ // #i37739# A simple 'MakeFrames' after the node sorting
// does not work if the table is inside a frame and has no prev/next.
const sal_uLong nIdx = pTableNd->GetIndex();